<template>
  <a-modal
    :title="title"
    :width="1250"
    :visible="visible"
    :confirmLoading="confirmLoading"
    @ok="handleOk"
    @cancel="handleCancel"
    cancelText="关闭"
  >

    <a-spin :spinning="confirmLoading">
      <a-form :form="form">
        <!-- 查询区域 -->
        <div class="table-page-search-wrapper">
          <a-form
            layout="inline"
            @keyup.enter.native="searchQuery"
          >
            <a-row :gutter="24">
              <a-col
                :md="6"
                :sm="8"
              >
                <a-form-item label="标准编号">
                  <a-input
                    placeholder="请输入标准编号检索"
                    v-model="queryParam.num"
                  ></a-input>
                </a-form-item>
              </a-col>

              <a-col
                :md="6"
                :sm="8"
              >
                <a-form-item label="设备名称">
                  <a-input
                    placeholder="请输入设备名称检索"
                    v-model="queryParam.equipmentName"
                  ></a-input>
                </a-form-item>
              </a-col>
              <a-col
                :md="6"
                :sm="8"
              >
                <a-button
                  type="primary"
                  @click="searchQuery"
                  icon="search"
                >查询</a-button>
                <a-button
                  @click="searchReset"
                  icon="reload"
                  style="margin-left:8px;"
                >重置</a-button>
              </a-col>
            </a-row>
            <a-row :gutter="24">
              <a-col :span="24">

              </a-col>
            </a-row>
          </a-form>
        </div>
        <div style="margin-top:8px;">
          <a-table
            ref="table"
            bordered
            size="middle"
            rowKey="id"
            :columns="columns"
            :dataSource="dataSource"
            :pagination="ipagination"
            :loading="loading"
            :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange, type: 'radio'}"
            @change="handleTableChange"
            :customRow="clickThenCheck"
          >
          </a-table>
        </div>
      </a-form>
    </a-spin>
  </a-modal>
</template>

<script>
import pick from 'lodash.pick'
import { httpAction, getAction } from '@/api/manage'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import JInput from '@/components/jeecg/JInput'
import JEllipsis from '@/components/jeecg/JEllipsis'//引入过长裁剪

export default {
  name: "DailyMaintenanceStandardList",
  mixins: [JeecgListMixin],
  components: {
    JInput,
    JEllipsis,
  },
  data() {
    return {
      title: "操作",
      visible: false,
      model: {},
      confirmLoading: false,
      form: this.$form.createForm(this),
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          align: 'center',
          width: 40,
          customRender: function (t, r, index) {
            return parseInt(index) + 1
          },
        },
        {
          title: '标准编码',
          align: 'center',
          dataIndex: 'num',
        },
        {
          title: '统一编码',
          align: 'center',
          dataIndex: 'equipmentNum',
        },
        {
          title: '设备名称',
          align: 'center',
          dataIndex: 'equipmentName',
        },
        {
          title: '设备型号',
          align: 'center',
          dataIndex: 'equipmentModel',
        },
        {
          title: '特种设备',
          align: 'center',
          dataIndex: 'specificEquipment',
        },
      ],
      url: {
        list: "/eam/maintenanceStandard/getMaintenanceStandard2List",
      },
      useId: '',
    }
  },
  methods: {
    searchQuery() {
      // this.queryParam = { type: "daily", delFlag: '0', versionStatus: '2', useId: this.useId, maintenanceType: '2' };
      this.queryParam.type = "daily";
      this.queryParam.delFlag = '0';
      this.queryParam.versionStatus = '2';
      this.queryParam.useId = this.useId;
      this.queryParam.maintenanceType = '2';
      this.loadData(1);
    },
    searchReset() {
      this.queryParam = { type: "daily", delFlag: '0', versionStatus: '2', useId: this.useId, maintenanceType: '2' };
      this.loadData(1)
    },
    list(useId) {
      this.visible = true;
      this.useId = useId;
      this.queryParam = { type: "daily", delFlag: '0', useId: useId, versionStatus: '2', maintenanceType: '2' };
      this.loadData(1);
    },
    clickThenCheck(record) {
      return {
        on: {
          click: (e) => {
            this.selectedRowRecord = record;
            this.onSelectChange(record.id.split(","), [record]);
          }
        }
      };
    },
    onSelectChange(selectedRowKeys, selectedRows) {
      this.selectedRowKeys = selectedRowKeys;
      this.selectedRowRecord = selectedRows[0];
    },
    close() {
      this.queryParam = {};
      this.$emit('close');
      this.visible = false;
    },
    handleOk() {
      const that = this;
      // 触发表单验证
      if (that.selectedRowKeys.length > 0) {
        if (that.selectedRowRecord.id != null && that.selectedRowRecord.id != "") {
          that.$emit('sendMaintenanceStandardRecord', { record: that.selectedRowRecord });
          that.close();
        } else {
          that.$message.error("请选择保养标准！")
        }
      } else {
        that.$message.error("请选择保养标准！")
      }
    },
    handleCancel() {
      this.close();
    }
  }
}
</script>

<style scoped>
@import '~@assets/less/common.less';
rozenRowClass {
  color: #c9c9c9;
}
.success {
  color: green;
}
.error {
  color: red;
}
.fontweight {
  font-weight: bold;
}
.ant-card {
  margin-left: -30px;
  margin-right: -30px;
}
.fontweight {
  font-weight: bold;
}
</style>